@@ -54,13 +54,7 @@ def _obsolete_line_fold(lines):
 
 def _decode_header_lines(lines):
     for line in _obsolete_line_fold(lines):
-        # _obsolete_line_fold yields either bytearray or bytes objects. On
-        # Python 3, validate() takes either and returns matches as bytes. But
-        # on Python 2, validate can return matches as bytearrays, so we have
-        # to explicitly cast back.
-        matches = validate(
-            header_field_re, bytes(line), "illegal header line: {!r}", bytes(line)
-        )
+        matches = validate(header_field_re, line, "illegal header line: {!r}", line)
         yield (matches["field_name"], matches["field_value"])
 
 
@@ -70,6 +64,8 @@ request_line_re = re.compile(request_line.encode("ascii"))
 def maybe_read_from_IDLE_client(buf):
     lines = buf.maybe_extract_lines()
     if lines is None:
+        if buf.is_next_line_obviously_invalid_request_line():
+            raise LocalProtocolError("illegal request line")
         return None
     if not lines:
         raise LocalProtocolError("no request line received")
@@ -87,6 +83,8 @@ status_line_re = re.compile(status_line.encode("ascii"))
 def maybe_read_from_SEND_RESPONSE_server(buf):
     lines = buf.maybe_extract_lines()
     if lines is None:
+        if buf.is_next_line_obviously_invalid_request_line():
+            raise LocalProtocolError("illegal request line")
         return None
     if not lines:
         raise LocalProtocolError("no response line received")
@@ -127,7 +125,7 @@ class ContentLengthReader:
 chunk_header_re = re.compile(chunk_header.encode("ascii"))
 
 
-class ChunkedReader(object):
+class ChunkedReader:
     def __init__(self):
         self._bytes_in_chunk = 0
         # After reading a chunk, we have to throw away the trailing \r\n; if
@@ -153,7 +151,7 @@ class ChunkedReader(object):
         assert self._bytes_to_discard == 0
         if self._bytes_in_chunk == 0:
             # We need to refill our chunk count
-            chunk_header = buf.maybe_extract_until_next(b"\r\n")
+            chunk_header = buf.maybe_extract_next_line()
             if chunk_header is None:
                 return None
             matches = validate(
@@ -163,9 +161,7 @@ class ChunkedReader(object):
                 chunk_header,
             )
             # XX FIXME: we discard chunk extensions. Does anyone care?
-            # We convert to bytes because Python 2's `int()` function doesn't
-            # work properly on bytearray objects.
-            self._bytes_in_chunk = int(bytes(matches["chunk_size"]), base=16)
+            self._bytes_in_chunk = int(matches["chunk_size"], base=16)
             if self._bytes_in_chunk == 0:
                 self._reading_trailer = True
                 return self(buf)
@@ -191,7 +187,7 @@ class ChunkedReader(object):
         )
 
 
-class Http10Reader(object):
+class Http10Reader:
     def __call__(self, buf):
         data = buf.maybe_extract_at_most(999999999)
         if data is None:
